% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/cache.R
\name{cBioCache-deprecated}
\alias{cBioCache-deprecated}
\alias{removeDataCache}
\title{Deprecated cache helper functions}
\usage{
removeDataCache(
  api,
  studyId = NA_character_,
  genePanelId = NA_character_,
  genes = NA_character_,
  molecularProfileIds = NULL,
  sampleListId = NULL,
  sampleIds = NULL,
  by = c("entrezGeneId", "hugoGeneSymbol"),
  dry.run = TRUE,
  ...
)
}
\arguments{
\item{api}{An API object of class `cBioPortal` from the `cBioPortal`
function}

\item{studyId}{character(1) Indicates the "studyId" as taken from
`getStudies`}

\item{genePanelId}{character(1) Identifies the gene panel, as obtained
from the `genePanels` function}

\item{genes}{character() Either Entrez gene identifiers or Hugo gene
symbols. When included, the 'by' argument indicates the type of
identifier provided and 'genePanelId' is ignored. Preference is
given to Entrez IDs due to faster query responses.}

\item{molecularProfileIds}{character() A vector of molecular profile IDs}

\item{sampleListId}{character(1) A sample list identifier as obtained from
`sampleLists()``}

\item{sampleIds}{character() Sample identifiers}

\item{by}{character(1) Either 'entrezGeneId' or 'hugoGeneSymbol' for row
metadata (default: 'entrezGeneId')}

\item{dry.run}{logical Whether or not to remove cache files (default TRUE).}

\item{...}{Additional arguments to lower level API functions}
}
\value{
removeDataCache: The path to the cache location when
  `dry.run = FALSE` if the file exists. Otherwise, when `dry.run = TRUE`,
  the function return the output of the `file.remove` operation.
}
\description{
`cBioPortalData` no longer caches data from API responses;
  therefore, `removeDataCache` is no longer needed. It will be removed
  as soon as the next release of Bioconductor.
}
\section{removeDataCache}{

Remove the computed cache location based on the function inputs to
`cBioPortalData()`. To remove the cache, simply replace the
`cBiocPortalData()` function name with `removeDataCache()`; see the example.
If the computed cache location is not found, it will return an empty vector.
}

\examples{

cbio <- cBioPortal()

cBioPortalData(
    cbio, by = "hugoGeneSymbol",
    studyId = "acc_tcga",
    genePanelId = "AmpliSeq",
    molecularProfileIds =
        c("acc_tcga_rppa", "acc_tcga_linear_CNA", "acc_tcga_mutations")
)

removeDataCache(
    cbio, by = "hugoGeneSymbol",
    studyId = "acc_tcga",
    genePanelId = "AmpliSeq",
    molecularProfileIds =
        c("acc_tcga_rppa", "acc_tcga_linear_CNA", "acc_tcga_mutations"),
    dry.run = TRUE
)

}
